# -*- coding: utf-8 -*-

"""Top-level package for test_cookiecutter."""

__author__ = """Marc-Olivier Buob"""
__email__ = 'marc-olivier.buob@nokia-bell-labs.com'
__version__ = '0.1.1'

from .SubPackage1.MyClass1 import MyClass1
from .SubPackage2.MyClass2 import MyClass2
from .SubPackage2.MyClass3 import MyClass3
